<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="el">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Επιτυχής επαλήθευση</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Επαλήθευση απέτυχε, απέμεινε μόνο μία προσπάθεια </translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Επαλήθευση του δακτυλικού αποτυπώματος σας</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Επιτυχής επαλήθευση</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Επαλήθευση απέτυχε, απέμεινε μόνο μία προσπάθεια </translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Το δαχτυλικό αποτύπωμα κλειδώθηκε, παρακαλώ χρησημοποιήστε κωδικό πρόσβασης</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Επιτυχής επαλήθευση</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Επαλήθευση απέτυχε, απέμεινε μόνο μία προσπάθεια </translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthPasskey</name>
    <message>
        <source>Please plug in the security key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Identifying the security key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Επιτυχής επαλήθευση</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Επαλήθευση απέτυχε, απέμεινε μόνο μία προσπάθεια </translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Λάθος Κωδικός Πρόσβασης</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Κωδικός πρόσβασης</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Παρακαλώ προσθήστε ξανά σε 1 λεπτό</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Παρακαλώ προσθήστε ξανά σε 1 λεπτό</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Επιτυχής επαλήθευση</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Επαλήθευση απέτυχε, απέμεινε μόνο μία προσπάθεια </translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Λάθος PIN</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>Απαιτείται UKeyh</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Εισάγετε το PIN σας</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Παρακαλώ προσθήστε ξανά σε 1 λεπτό</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Λογαριασμός</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Ο κωδικός πρόσβασης έληξε, παρακαλώ αλλάξτε τον</translation>
    </message>
    <message>
        <source>Your password has expired. Please contact the administrator to change it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Terminal locked, please contact administrator</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DeepinAuthFramework</name>
    <message>
        <source>Wrong Password</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Λάθος λογαριασμός</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Λάθος Κωδικός Πρόσβασης</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>The reason of inhibit.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LighterGreeter</name>
    <message>
        <source>Standard Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Κλείδωμα Οθόνης</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Αποτυχία κλειδώματος οθόνης</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Τέλος χρόνου επαλήθευσης δακτυλικού αποτυπώματος, παρακαλώ εισάγετε τον κωδικό πρόσβασης χειροκίνητα</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Αποτυχία αντιστοίχισης δακτυλικού αποτυπώματος</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Οι παραπάνω χρήστες εξακολουθούν να είναι συνδεδεμένοι και τα δεδομένα θα χαθούν λόγω τερματισμού λειτουργίας, είστε βέβαιοι ότι θέλετε να τερματίσετε τη λειτουργία;</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Οι παραπάνω χρήστες εξακολουθούν να είναι συνδεδεμένοι και τα δεδομένα θα χαθούν λόγω επανεκκίνησης, είστε βέβαιοι ότι θέλετε να επανεκκινήσετε;</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Τερματισμός λειτουργίας</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Επανεκκίνηση</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Αναστολή</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Αδρανοποίηση</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Κλείδωμα</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Έξοδος χρήστη</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Εναλλαγή χρήστη</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Εναλλαγή συστήματος</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Εκκίνηση παρακολούθησης συστήματος</translation>
    </message>
</context>
<context>
    <name>UdcpMFALoginWidget</name>
    <message>
        <source>发送验证码</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>请输入手机号</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>请输入验证码</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>获取验证码</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please plug in and then install updates.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UsersWithTheSameName</name>
    <message>
        <source>Return</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please select the account for login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Local Account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Domain Account</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Τα προγράμματα εμποδίζουν τον υπολογιστή από το να απενεργοποιηθεί, και η εξαναγκασμένη απενεργοποίηση μπορεί να προκαλέσει απώλεια δεδομένων.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Για κλείσιμο του προγράμματος, πατήστε Άκυρο, και μετά κλείστε το πρόγραμμα.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Τα προγράμματα εμποδίζουν τον υπολογιστή από το να επανεκκινηθεί, και η εξαναγκασμένη επανεκκίνηση μπορεί να προκαλέσει απώλεια δεδομένων.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Τα προγράμματα εμποδίζουν τον υπολογιστή από το να τεθεί σε αναστολή λειτουργίας, και η εξαναγκασμένη αναστολή λειτουργίας μπορεί να προκαλέσει απώλεια δεδομένων.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Τα προγράμματα εμποδίζουν τον υπολογιστή από το να αδρανοποιηθεί, και η εξαναγκασμένη αδρανοποίηση μπορεί να προκαλέσει απώλεια δεδομένων.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Τα προγράμματα εμποδίζουν την έξοδο χρήστη από τον υπολογιστή, και η εξαναγκασμένη έξοδος μπορεί να προκαλέσει απώλεια δεδομένων.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Τερματισμός λειτουργίας</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Επανεκκίνηση</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Αναστολή λειτουργίας</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Αδρανοποίηση</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Έξοδος χρήστη</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Σίγουρα θέλετε να γίνει απενεργοποίηση;</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Σίγουρα θέλετε να γίνει επανεκκίνηση;</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Σίγουρα θέλετε να γίνει έξοδος χρήστη;</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Closing the programs and shutting down, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Closing the programs and rebooting, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Closing the programs and logging out, please wait...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::AssistLoginWidget</name>
    <message>
        <source>Automatic login</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Ενεργοποίηση</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Απενεργοποίηση</translation>
    </message>
</context>
</TS>